@@ -346,8 +346,9 @@ class IntelDisassembler(object):
                         LOGGER.debug("  analyzeFunction() found ending instruction @0x%08x", i_address)
                     elif previous_address and i_address != start_addr and previous_mnemonic == "call":
                         instruction_sequence = [ins for ins in self.capstone.disasm(self._getDisasmWindowBuffer(i_address), i_address)]
-                        if self.fc_manager.isAlignmentSequence(instruction_sequence) or self.fc_manager.isFunctionCandidate(i_address):
+                        if (not self.disassembly.language == "go" and self.fc_manager.isAlignmentSequence(instruction_sequence)) or self.fc_manager.isFunctionCandidate(i_address):
                             # LLVM and GCC sometimes tends to produce lots of tailcalls that basically mess with function end detection, we cut whenever we find effective nops after calls
+                            # however, Go tends to insert alignment NOPs after calls, too, but in this case, they are no tailcall indicator
                             LOGGER.debug("    current function: 0x%x ---> ran into alignment sequence after call -> 0x%08x, cutting block here.", start_addr, i_address)
                             state.setBlockEndingInstruction(True)
                             state.endBlock()
